@@ -7,44 +7,61 @@ import re
 from pathlib import Path
 from datetime import datetime
 from html.parser import HTMLParser
-from typing import List, Dict, Optional, Any, Callable, Iterable, Tuple
+from typing import List, Optional, Any, Callable, Iterable, Tuple
 from collections import OrderedDict
 from urllib.parse import unquote
 import pytz
 
 from ...core.time import abbr_to_timezone
 
-# Mar 8, 2018, 5:14:40 PM
-_TIME_FORMAT = "%b %d, %Y, %I:%M:%S %p"
+
+# NOTE: https://bugs.python.org/issue22377 %Z doesn't work properly
+_TIME_FORMATS = [
+    "%b %d, %Y, %I:%M:%S %p",  # Mar 8, 2018, 5:14:40 PM
+    "%d %b %Y, %H:%M:%S",
+]
 
 
 # ugh. something is seriously wrong with datetime, it wouldn't parse timezone aware UTC timestamp :(
 def parse_dt(s: str) -> datetime:
-    fmt = _TIME_FORMAT
-    #
-    # ugh. https://bugs.python.org/issue22377 %Z doesn't work properly
-
     end = s[-3:]
     tz: Any # meh
     if end == ' PM' or end == ' AM':
         # old takeouts didn't have timezone
         # hopefully it was utc? Legacy, so no that much of an issue anymore..
+        # todo although maybe worth adding timezone from location provider?
         tz = pytz.utc
     else:
         s, tzabbr = s.rsplit(maxsplit=1)
         tz = abbr_to_timezone(tzabbr)
 
-    dt = datetime.strptime(s, fmt)
-    dt = tz.localize(dt)
-    return dt
+    dt: Optional[datetime] = None
+    for fmt in _TIME_FORMATS:
+        try:
+            dt = datetime.strptime(s, fmt)
+            break
+        except ValueError:
+            continue
+    if dt is None:
+        raise RuntimeError("None of formats {} matched {}", _TIME_FORMATS, dt)
+    return tz.localize(dt)
 
 
-def test_parse_dt():
+def test_parse_dt() -> None:
     parse_dt('Jun 23, 2015, 2:43:45 PM')
     parse_dt('Jan 25, 2019, 8:23:48 AM GMT')
     parse_dt('Jan 22, 2020, 8:34:00 PM UTC')
     parse_dt('Sep 10, 2019, 8:51:45 PM MSK')
 
+    # this testcases are interesting: in pytz, abbr resolution might depend on the _current_ date!
+    # so these used to fail during winter
+    # you can see all the different values used in in _tzinfos field
+    parse_dt('Jun 01, 2018, 11:00:00 PM BST')
+    parse_dt('Jun 01, 2018, 11:00:00 PM PDT')
+    parse_dt('Feb 01, 2018, 11:00:00 PM PST')
+
+    parse_dt('6 Oct 2020, 14:32:28 PDT')
+
 
 class State(Enum):
     OUTSIDE = 0
