@@ -1,10 +1,13 @@
 """
 [[https://www.instapaper.com][Instapaper]] bookmarks, highlights and annotations
 """
-from dataclasses import dataclass
-from typing import Optional
+REQUIRES = [
+    'git+https://github.com/karlicoss/instapexport',
+]
 
-from .core import Paths, PathIsh
+from dataclasses import dataclass
+
+from .core import Paths
 
 from my.config import instapaper as user_config
 
@@ -17,30 +20,16 @@ class instapaper(user_config):
     # path[s]/glob to the exported JSON data
     export_path : Paths
 
-    # path to a local clone of instapexport
-    # alternatively, you can put the repository (or a symlink) in $MY_CONFIG/my/config/repos/instapexport
-    instapexport: Optional[PathIsh] = None
-
-    @property
-    def dal_module(self):
-        rpath = self.instapexport
-        if rpath is not None:
-            from .core.common import import_dir
-            return import_dir(rpath, '.dal')
-        else:
-            import my.config.repos.instapexport.dal as dal
-            return dal
-
 
 from .core.cfg import make_config
 config = make_config(instapaper)
 
 
-from typing import TYPE_CHECKING
-if TYPE_CHECKING:
-    import my.config.repos.instapexport.dal as dal
-else:
-    dal = config.dal_module
+try:
+    from instapexport import dal
+except ModuleNotFoundError as e:
+    from .core.compat import pre_pip_dal_handler
+    dal = pre_pip_dal_handler('instapexport', e, config, requires=REQUIRES)
 
 ############################
 
@@ -64,6 +53,12 @@ def pages() -> Iterable[Page]:
     return _dal().pages()
 
 
+def stats():
+    from .core import stat
+    return stat(pages)
+
+### misc
+
 # TODO dunno, move this to private?
 def is_todo(hl: Highlight) -> bool:
     note = hl.note or ''
