@@ -3,12 +3,12 @@ import csv
 from datetime import datetime
 from typing import Iterator, List, NamedTuple
 
-from ..common import get_files
+from ..core import get_files
 
 from my.config import imdb as config
 
 def _get_last():
-    return max(get_files(config.export_path, glob='*.csv'))
+    return max(get_files(config.export_path))
 
 
 class Movie(NamedTuple):
@@ -38,11 +38,3 @@ def get_movies() -> List[Movie]:
 
 def test():
     assert len(get_movies()) > 10
-
-
-def main():
-    for movie in get_movies():
-        print(movie)
-
-if __name__ == '__main__':
-    main()
