@@ -8,6 +8,7 @@ from more_itertools import unique_everseen
 
 # TODO add proper Protocol for Tweet
 Tweet = Any
+TweetId = str
 
 
 from my.core import warn_if_empty, Res
@@ -17,5 +18,13 @@ def merge_tweets(*sources: Iterator[Res[Tweet]]) -> Iterator[Res[Tweet]]:
         if isinstance(r, Exception):
             return str(r)
         else:
-            return r.id_str
+            # using both fields as key makes it a bit easier to spot TZ issues
+            return (r.id_str, r.created_at)
     yield from unique_everseen(chain(*sources), key=key)
+
+
+def permalink(*, screen_name: str, id: str) -> str:
+    return f'https://twitter.com/{screen_name}/status/{id}'
+
+# NOTE: tweets from archive are coming sorted by created_at
+# NOTE: tweets from twint are also sorted by created_at?
